"""
Django settings for shiftregister project.

Generated by 'django-admin startproject' using Django 4.0.3.

For more information on this file, see
https://docs.djangoproject.com/en/4.0/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/4.0/ref/settings/
"""

from pathlib import Path
from os import getenv
import sentry_sdk
from sentry_sdk.integrations.celery import CeleryIntegration
from sentry_sdk.integrations.django import DjangoIntegration
from django.contrib.messages import constants as messages

# Build paths inside the project like this: BASE_DIR / 'subdir'.
BASE_DIR = Path(__file__).resolve().parent.parent


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/4.0/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = getenv(
    "SECRET_KEY", "django-insecure-pdgzgd_!w&&cfqc%r&!v_^6pgf!sza=2wim67()!(kaf7_6-5)"
)

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = getenv("ENVIRONMENT", "development") == "development"

ALLOWED_HOSTS = list(filter(lambda s: s != "", getenv("ALLOWED_HOSTS", "").split(",")))


# Application definition

INSTALLED_APPS = [
    "dynamic_preferences",
    "shiftregister.app.apps.AppConfig",
    "shiftregister.core.apps.CoreConfig",
    "shiftregister.fallback.apps.FallbackConfig",
    "shiftregister.importer.apps.ImporterConfig",
    "shiftregister.metrics.apps.MetricsConfig",
    "shiftregister.pages.apps.PagesConfig",
    "shiftregister.signage.apps.SignageConfig",
    "shiftregister.team.apps.TeamConfig",
    "django.contrib.admin",
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.humanize",
    "django.contrib.sessions",
    "django.contrib.messages",
    "django.contrib.staticfiles",
    "phonenumber_field",
]

MIDDLEWARE = [
    "django.middleware.security.SecurityMiddleware",
    "django.contrib.sessions.middleware.SessionMiddleware",
    "django.middleware.common.CommonMiddleware",
    "django.middleware.csrf.CsrfViewMiddleware",
    "django.contrib.auth.middleware.AuthenticationMiddleware",
    "django.contrib.messages.middleware.MessageMiddleware",
    "django.middleware.clickjacking.XFrameOptionsMiddleware",
    "shiftregister.app.middleware.check_helper",
]

ROOT_URLCONF = "shiftregister.urls"

LOGIN_URL = "/admin/login/"

TEMPLATES = [
    {
        "BACKEND": "django.template.backends.django.DjangoTemplates",
        "DIRS": [],
        "APP_DIRS": True,
        "OPTIONS": {
            "context_processors": [
                "django.template.context_processors.debug",
                "django.template.context_processors.request",
                "django.contrib.auth.context_processors.auth",
                "django.contrib.messages.context_processors.messages",
                "shiftregister.app.context_processors.proc",
                "shiftregister.core.context_processors.nav",
            ],
        },
    },
]

WSGI_APPLICATION = "shiftregister.wsgi.application"


# Database
# https://docs.djangoproject.com/en/4.0/ref/settings/#databases

DATABASES = {
    "default": {
        "ENGINE": "django.db.backends." + getenv("DB_ENGINE", "sqlite3"),
        "NAME": getenv("DB_NAME", BASE_DIR / "db.sqlite3"),
        "USER": getenv("DB_USER", ""),
        "PASSWORD": getenv("DB_PASSWORD", ""),
        "HOST": getenv("DB_HOST", ""),
        "PORT": getenv("DB_PORT", ""),
    }
}


# Password validation
# https://docs.djangoproject.com/en/4.0/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        "NAME": "django.contrib.auth.password_validation.UserAttributeSimilarityValidator",
    },
    {
        "NAME": "django.contrib.auth.password_validation.MinimumLengthValidator",
    },
    {
        "NAME": "django.contrib.auth.password_validation.CommonPasswordValidator",
    },
    {
        "NAME": "django.contrib.auth.password_validation.NumericPasswordValidator",
    },
]


# Internationalization
# https://docs.djangoproject.com/en/4.0/topics/i18n/

LANGUAGE_CODE = "de-de"

TIME_ZONE = "Europe/Berlin"

USE_I18N = True

USE_TZ = True


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/4.0/howto/static-files/

STATIC_ROOT = "/opt/shiftregister/static"
STATIC_URL = "static/"

STATICFILES_DIRS = [
    BASE_DIR / "assets",
]

# Default primary key field type
# https://docs.djangoproject.com/en/4.0/ref/settings/#default-auto-field

DEFAULT_AUTO_FIELD = "django.db.models.BigAutoField"

CELERY_BROKER_URL = getenv("CELERY_BROKER_URL", "amqp://guest:guest@localhost:5672//")

CELERY_RESULT_BACKEND = getenv("CELERY_RESULT_BACKEND", "redis://")

CELERY_BEAT_SCHEDULE = {
    "import-shifts-every-60-seconds": {
        "task": "shiftregister.importer.tasks.import_shifts",
        "schedule": float(getenv("SHIFT_IMPORT_INTERVAL", 60.0)),  # seconds
    },
    "send-messages-every-120-seconds": {
        "task": "shiftregister.app.tasks.send_messages",
        "schedule": float(getenv("MESSAGE_SEND_INTERVAL", 120.0)),  # seconds
    },
    "send-reminders-every-300-seconds": {
        "task": "shiftregister.app.tasks.send_reminders",
        "schedule": float(getenv("REMINDER_SEND_INTERVAL", 300.0)),  # seconds
    },
    "receive-messages-every-300-seconds": {
        "task": "shiftregister.team.tasks.receive_messages",
        "schedule": float(getenv("MESSAGE_RECEIVE_INTERVAL", 300.0)),  # seconds
    },
}

CELERY_BEAT_SCHEDULE_FILENAME = str(BASE_DIR / "storage" / "celerybeat-schedule")

if getenv("SENTRY_DSN"):
    sentry_sdk.init(
        dsn=getenv("SENTRY_DSN"),
        integrations=[CeleryIntegration(), DjangoIntegration()],
        auto_session_tracking=False,
        traces_sample_rate=0,
    )

PHONENUMBER_DEFAULT_REGION = "DE"

MESSAGE_TAGS = {
    messages.ERROR: "danger",
}

SIPGATE_SMS_EXTENSION = getenv("SIPGATE_SMS_EXTENSION")

SIPGATE_TOKEN_ID = getenv("SIPGATE_TOKEN_ID")

SIPGATE_TOKEN = getenv("SIPGATE_TOKEN")

SIPGATE_INCOMING_TOKEN_ID = getenv("SIPGATE_INCOMING_TOKEN_ID")

SIPGATE_INCOMING_TOKEN = getenv("SIPGATE_INCOMING_TOKEN")
